==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/model/MessageReceiptSpec.java <==
package it.auties.whatsapp.model.message.model;

import it.auties.whatsapp.model.message.model.MessageReceipt;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class MessageReceiptSpec {
    public static byte[] encode(MessageReceipt protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var deliveredTimestampSeconds = protoInputObject.deliveredTimestampSeconds();
if(deliveredTimestampSeconds != null) {
var deliveredTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(deliveredTimestampSeconds);
if(deliveredTimestampSeconds0 != null) {
outputStream.writeInt64(2, deliveredTimestampSeconds0);
}
}
var readTimestampSeconds = protoInputObject.readTimestampSeconds();
if(readTimestampSeconds != null) {
var readTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(readTimestampSeconds);
if(readTimestampSeconds0 != null) {
outputStream.writeInt64(3, readTimestampSeconds0);
}
}
var playedTimestampSeconds = protoInputObject.playedTimestampSeconds();
if(playedTimestampSeconds != null) {
var playedTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(playedTimestampSeconds);
if(playedTimestampSeconds0 != null) {
outputStream.writeInt64(4, playedTimestampSeconds0);
}
}
      if(protoInputObject.deliveredJids() != null) {
       for(var deliveredJidsEntry : protoInputObject.deliveredJids()) {
var deliveredJids = deliveredJidsEntry;
if(deliveredJids != null) {
var deliveredJids0 = deliveredJids.toProtobufValue();
if(deliveredJids0 != null) {
outputStream.writeString(5, deliveredJids0);
}
}
       }
      }
      if(protoInputObject.readJids() != null) {
       for(var readJidsEntry : protoInputObject.readJids()) {
var readJids = readJidsEntry;
if(readJids != null) {
var readJids0 = readJids.toProtobufValue();
if(readJids0 != null) {
outputStream.writeString(6, readJids0);
}
}
       }
      }
      return outputStream.toByteArray();
    }

    public static MessageReceipt decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        java.lang.Long deliveredTimestampSeconds = null;
        java.lang.Long readTimestampSeconds = null;
        java.lang.Long playedTimestampSeconds = null;
        java.util.Set<it.auties.whatsapp.model.jid.Jid> deliveredJids = new java.util.HashSet<it.auties.whatsapp.model.jid.Jid>();
        java.util.Set<it.auties.whatsapp.model.jid.Jid> readJids = new java.util.HashSet<it.auties.whatsapp.model.jid.Jid>();
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 2 -> deliveredTimestampSeconds = inputStream.readInt64();
                case 3 -> readTimestampSeconds = inputStream.readInt64();
                case 4 -> playedTimestampSeconds = inputStream.readInt64();
                case 5 -> deliveredJids.add(it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString()));
                case 6 -> readJids.add(it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString()));
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.message.model.MessageReceipt(deliveredTimestampSeconds, readTimestampSeconds, playedTimestampSeconds, deliveredJids, readJids);
    }

}

==> cobalt-0.0.4-sources.jar: it/auties/whatsapp/model/message/model/MessageReceiptSpec.java <==
package it.auties.whatsapp.model.message.model;

import it.auties.whatsapp.model.message.model.MessageReceipt;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class MessageReceiptSpec {
    public static byte[] encode(MessageReceipt protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var deliveredTimestampSeconds = protoInputObject.deliveredTimestampSeconds();
if(deliveredTimestampSeconds != null) {
var deliveredTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(deliveredTimestampSeconds);
if(deliveredTimestampSeconds0 != null) {
outputStream.writeInt64(2, deliveredTimestampSeconds0);
}
}
var readTimestampSeconds = protoInputObject.readTimestampSeconds();
if(readTimestampSeconds != null) {
var readTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(readTimestampSeconds);
if(readTimestampSeconds0 != null) {
outputStream.writeInt64(3, readTimestampSeconds0);
}
}
var playedTimestampSeconds = protoInputObject.playedTimestampSeconds();
if(playedTimestampSeconds != null) {
var playedTimestampSeconds0 = it.auties.protobuf.extension.OptionalExtension.toNullableLong(playedTimestampSeconds);
if(playedTimestampSeconds0 != null) {
outputStream.writeInt64(4, playedTimestampSeconds0);
}
}
      if(protoInputObject.deliveredJids() != null) {
       for(var deliveredJidsEntry : protoInputObject.deliveredJids()) {
var deliveredJids = deliveredJidsEntry;
if(deliveredJids != null) {
var deliveredJids0 = deliveredJids.toString();
if(deliveredJids0 != null) {
outputStream.writeString(5, deliveredJids0);
}
}
       }
      }
      if(protoInputObject.readJids() != null) {
       for(var readJidsEntry : protoInputObject.readJids()) {
var readJids = readJidsEntry;
if(readJids != null) {
var readJids0 = readJids.toString();
if(readJids0 != null) {
outputStream.writeString(6, readJids0);
}
}
       }
      }
      return outputStream.toByteArray();
    }

    public static MessageReceipt decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        java.lang.Long deliveredTimestampSeconds = null;
        java.lang.Long readTimestampSeconds = null;
        java.lang.Long playedTimestampSeconds = null;
        java.util.Set<it.auties.whatsapp.model.jid.Jid> deliveredJids = new java.util.HashSet<it.auties.whatsapp.model.jid.Jid>();
        java.util.Set<it.auties.whatsapp.model.jid.Jid> readJids = new java.util.HashSet<it.auties.whatsapp.model.jid.Jid>();
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 2 -> deliveredTimestampSeconds = inputStream.readInt64();
                case 3 -> readTimestampSeconds = inputStream.readInt64();
                case 4 -> playedTimestampSeconds = inputStream.readInt64();
                case 5 -> deliveredJids.add(it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString()));
                case 6 -> readJids.add(it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString()));
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.message.model.MessageReceipt(deliveredTimestampSeconds, readTimestampSeconds, playedTimestampSeconds, deliveredJids, readJids);
    }

}
